package com.ruoyi.web.controller.system.filemanager;

import java.util.ArrayList;
import java.util.List;

import com.ruoyi.system.domain.TdFileProvide;
import com.ruoyi.system.domain.TdFileReceive;
import com.ruoyi.system.service.ITdFileProvideService;
import com.ruoyi.system.service.ITdFileReceiveService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TdFileDestory;
import com.ruoyi.system.service.ITdFileDestoryService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 涉密文件销毁Controller
 * 
 * @author ruoyi
 * @date 2024-05-15
 */
@Controller
@RequestMapping("/system/filedestory")
public class TdFileDestoryController extends BaseController
{
    private String prefix = "system/filedestory";

    @Autowired
    private ITdFileDestoryService tdFileDestoryService;
    @Autowired
    private ITdFileReceiveService tdFileReceiveService;
    @Autowired
    private ITdFileProvideService tdFileProvideService;

    @RequiresPermissions("system:filedestory:view")
    @GetMapping()
    public String filedestory()
    {
        return prefix + "/filedestory";
    }

    /**
     * 查询涉密文件销毁列表
     */
    @RequiresPermissions("system:filedestory:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdFileDestory tdFileDestory,ModelMap mmap)
    {
        startPage();
        List<TdFileDestory> list = tdFileDestoryService.selectTdFileDestoryList(tdFileDestory);
        List<TdFileReceive> tdFileReceiveList = new ArrayList<>();
        List<List> list1 = new ArrayList<>();
        for (TdFileDestory tdFileDestorylist : list){
            TdFileReceive tdFileReceive = tdFileReceiveService.selectTdFileReceiveByReceiveId(tdFileDestorylist.getReceiveId());
            tdFileReceiveList.add(tdFileReceive);
        }
        list1.add(list);
        list1.add(tdFileReceiveList);
        return getDataTable(list1);
    }

    /**
     * 导出涉密文件销毁列表
     */
    @RequiresPermissions("system:filedestory:export")
    @Log(title = "涉密文件销毁", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(TdFileDestory tdFileDestory)
    {
        List<TdFileDestory> list = tdFileDestoryService.selectTdFileDestoryList(tdFileDestory);
        ExcelUtil<TdFileDestory> util = new ExcelUtil<TdFileDestory>(TdFileDestory.class);
        return util.exportExcel(list, "涉密文件销毁数据");
    }

    /**
     * 修改涉密文件销毁
     */
    @RequiresPermissions("system:filedestory:edit")
    @GetMapping("/edit/{destoryId}")
    public String edit(@PathVariable("destoryId") Long destoryId, ModelMap mmap)
    {
        TdFileDestory tdFileDestory = tdFileDestoryService.selectTdFileDestoryByDestoryId(destoryId);
        String fileId = (tdFileReceiveService.selectTdFileReceiveByReceiveId(tdFileDestory.getReceiveId())).getFileId();
        TdFileProvide tdFileProvide = tdFileProvideService.selectTdFileProvideByFileId(fileId);
        mmap.put("tdFileProvide", tdFileProvide);
        mmap.put("tdFileDestory", tdFileDestory);
        return prefix + "/edit";
    }

    /**
     * 修改保存涉密文件销毁
     */
    @RequiresPermissions("system:filedestory:edit")
    @Log(title = "涉密文件销毁", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(TdFileDestory tdFileDestory)
    {
        return toAjax(tdFileDestoryService.updateTdFileDestory(tdFileDestory));
    }

    /**
     * 删除涉密文件销毁
     */
    @RequiresPermissions("system:filedestory:remove")
    @Log(title = "涉密文件销毁", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(tdFileDestoryService.deleteTdFileDestoryByDestoryIds(ids));
    }

    /**
     * 涉密文件销毁详情
     */
    @RequiresPermissions("system:filedestory:detail")
    @GetMapping("/detail/{destoryId}")
    public String detail(@PathVariable("destoryId") Long destoryId, ModelMap mmap)
    {
        TdFileDestory tdFileDestory = tdFileDestoryService.selectTdFileDestoryByDestoryId(destoryId);
        String fileId = (tdFileReceiveService.selectTdFileReceiveByReceiveId(tdFileDestory.getReceiveId())).getFileId();
        TdFileProvide tdFileProvide = tdFileProvideService.selectTdFileProvideByFileId(fileId);
        mmap.put("tdFileProvide", tdFileProvide);
        mmap.put("tdFileDestory", tdFileDestory);
        return prefix + "/detail";
    }

}
